@@ -1020,6 +1020,9 @@ class StrictRedisExtensions(BaseRedisExpires, StrictRedis):
         return '{0}queue:{1}'.format(KEY_PREFIX, queue)
 
     def execute_later(self, queue, name, args=None, delayed=KEY_PREFIX + 'delayed:default', delay=0, short_uuid=False, enable_queue=False):
+        """
+        Producer of delay execute.
+        """
         identifier = self.__uuid(short_uuid)
         item = json.dumps([identifier, queue, name, args])
         if delay > 0:
@@ -1051,7 +1054,24 @@ class StrictRedisExtensions(BaseRedisExpires, StrictRedis):
         logger.info('  * Release lock: {0}'.format(identifier))
         return self.delete_lock(identifier)
 
-    def poll_queue(self, callbacks={}, delayed=KEY_PREFIX + 'delayed:default', unlocked_warning_func=None, enable_queue=False, release_lock_when_launch=True, release_lock_key=None, release_lock_key_expire=1800, release_lock_when_error=True):
+    def poll_queue(self, callbacks={}, delayed=KEY_PREFIX + 'delayed:default', unlocked_warning_func=None, enable_auto_zrem=False, enable_queue=False, release_lock_when_launch=True, release_lock_key=None, release_lock_key_expire=1800, release_lock_when_error=True):
+        """
+        Consumer of delay execute.
+
+        ``unlocked_warning_func`` indicates callback function when ``acquire_lock`` fail.
+
+        ``enable_auto_zrem`` indicates whether enable auto zrem or not. ``True`` for at most once, ``False`` for at least once.
+
+        ``enable_queue`` indicates whether enable queue or not.
+
+        ``release_lock_when_launch`` indicates whether release lock when launch or not. This is for ``restart``.
+
+        ``release_lock_key`` indicates acquire lock key when ``release_lock_when_launch``.
+
+        ``release_lock_key_expire`` indicates expire time of ``release_lock_key``.
+
+        ``release_lock_when_error`` indicates whether release lock when error or not.
+        """
         callbacks = {k: self.__callable_func(v) for k, v in iteritems(callbacks)}
         callbacks = {k: v for k, v in iteritems(callbacks) if v}
 
@@ -1080,24 +1100,28 @@ class StrictRedisExtensions(BaseRedisExpires, StrictRedis):
 
             locked = self.acquire_lock(identifier)
             if not locked:
-                # Call ``unlocked_warning_func`` if exists when ``acquire_lock`` fails
+                # Call ``unlocked_warning_func`` if exists when ``acquire_lock`` fail
                 if unlocked_warning_func:
                     unlocked_warning_func(queue, name, args)
                 continue
 
+            # At most once 最多消费一次
+            if enable_auto_zrem and self.zrem(delayed, item) and enable_queue:
+                self.rpush(self.__queue_key(queue), item)
+
             # Callbacks
             if queue in callbacks:
                 try:
                     callbacks[queue](name, args)
                 except Exception as e:
                     logger.error(e)
-                    if release_lock_when_error:
-                        self.release_lock(identifier, locked)
-                    continue
+                    if not release_lock_when_error:
+                        continue
+                    self.release_lock(identifier, locked)
 
-            if self.zrem(delayed, item):
-                if enable_queue:
-                    self.rpush(self.__queue_key(queue), item)
+            # At least once 最少消费一次
+            if not enable_auto_zrem and self.zrem(delayed, item) and enable_queue:
+                self.rpush(self.__queue_key(queue), item)
 
             self.release_lock(identifier, locked)
 
